Documentation of ``simframe``!
=========================================

| ``simframe`` is a framework to flexibly build scientific simulations.
| It comes with a variety of integration schemes and some infrastructure for writing and reading data files.

| To install ``simframe`` simply type
| ``pip install simframe``

| Please have a look at the following examples to learn how to use ``simframe``.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   1_simple_integration
   2_advanced_integration
   3_updating
   4_custom_schemes
   5_adaptive_schemes
   6_implicit_integration
   7_coupled_oscillators
   api



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
